==> oauth1-py3-1.0.1.tar.gz: oauth1-py3-1.0.1/setup.py <==
#!/usr/bin/env python
# Copyright (c) 2017 Leah Culver <leah.culver@gmail.com>
#					 William Marquardt <williammqt@gmail.com>
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
# THE SOFTWARE.

from setuptools import setup, find_packages

setup(name="oauth1-py3",
      version="1.0.1",
      description="Library for OAuth version 1.0a. (Python 3)",
      author="William Marquardt",
      author_email="williammqt@gmail.com",
      url="https://github.com/Navegg/oauth1-py3",
      donwload_url="https://github.com/Navegg/oauth1-py3/archive/1.0.1.tar.gz",
      classifiers= [
                    "Programming Language :: Python :: 3 :: Only"
                    ],
      packages = find_packages(),
      license = "MIT License",
      zip_safe = True)

==> oauth1-py3-1.0.2.tar.gz: oauth1-py3-1.0.2/setup.py <==
#!/usr/bin/env python
# Copyright (c) 2017 Leah Culver <leah.culver@gmail.com>
#					 William Marquardt <williammqt@gmail.com>
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
# THE SOFTWARE.

from setuptools import setup, find_packages

setup(name="oauth1-py3",
      version="1.0.2",
      description="Library for OAuth version 1.0a. (Python 3)",
      author="William Marquardt",
      author_email="williammqt@gmail.com",
      url="https://github.com/Navegg/oauth1-py3",
      packages = find_packages(),
      classifiers=[
        "Programming Language :: Python :: 3",
      ],
      license = "MIT License",
      zip_safe = True)
